@@ -1,12 +1,12 @@
 import unittest
 
-from scss.parser import Stylecheet
+from scss.parser import Stylesheet
 
 
 class TestSCSS( unittest.TestCase ):
 
     def setUp(self):
-        self.parser = Stylecheet()
+        self.parser = Stylesheet(options=dict(compress=True))
 
     def test_for(self):
         src = """
@@ -14,16 +14,19 @@ class TestSCSS( unittest.TestCase ):
                 $width: $src + 5px;
                 width: $width;
             }
-            $test: 9px;
-            $for: $test - 5;
             .test {
                 color: blue;
-                @for $i from 1 through $for {
+                @for $i from 1 through 4 {
                     .span-#{$i}{
                         @include test($i); }
                 }
             }
+
+            @for $i from 1 through 2 {
+                .span-#{$i}{
+                    color: red; }
+            }
         """
-        test = ".test {\n\tcolor: blue}\n\n.test .span-1 {\n\twidth: 6px}\n\n.test .span-2 {\n\twidth: 7px}\n\n.test .span-3 {\n\twidth: 8px}\n\n.test .span-4 {\n\twidth: 9px}"
-        out = self.parser.parse(src)
+        test = ".test{color:#00f}.test .span-1{width:6px}.test .span-2{width:7px}.test .span-3{width:8px}.test .span-4{width:9px}.span-1{color:#f00}.span-2{color:#f00}"
+        out = self.parser.loads(src)
         self.assertEqual(test, out)
