@@ -1,12 +1,26 @@
 import unittest
 
-from scss.parser import Stylecheet
+from scss.parser import Stylesheet
 
 
 class TestSCSS( unittest.TestCase ):
 
     def setUp(self):
-        self.parser = Stylecheet()
+        self.parser = Stylesheet(options=dict(compress=True))
+
+    def test_bugs(self):
+        src = """
+            .bug {
+                background: -webkit-gradient(linear, top left, 100% 100%, from(#ddd), to(#aaa));
+            }
+
+            .bug-moz {
+                background: -moz-linear-gradient (top, #DDD, #AAA);
+            }
+        """
+        test = ".bug{background:-webkit-gradient(linear, top left, 100% 100%, from(#ddd), to(#aaa))}.bug-moz{background:-moz-linear-gradient(top, #ddd, #aaa)}"
+        out = self.parser.loads(src)
+        self.assertEqual(test, out)
 
     def test_base(self):
         src = """
@@ -20,12 +34,11 @@ class TestSCSS( unittest.TestCase ):
                 a:hover { color: #036; }
                 @debug test; }
 
-            @media print {
-                @include z-base; }
+            @media print { @include z-base; }
 
             // Test comment
             /* Css comment */
-            body {
+            body:not(.test) {
                 $font: Georgia;
 
                 margin-bottom: .5em;
@@ -49,8 +62,8 @@ class TestSCSS( unittest.TestCase ):
                 border:2px; }
 
             """
-        test = "@charset utf-8;\n@import url(test);\n@media print { \na:hover, a:active {\n\toutline: none}\n\na, a:active, a:visited {\n\tcolor: #607890}\n\na:hover {\n\tcolor: #036}\n }/* Css comment */\n\nbody {\n\tmargin-bottom: .5em;\n\tfont-family: Georgia, sans-serif;\n\t*font: 13px/1.231 sans-serif}\n\n::selection {\n\tcolor: red}\n\n.test:hover {\n\tcolor: red}\n\n.test:hover:after {\n\tcontent: 'blue'}\n\npre, code, kbd, samp {\n\tfont: 12px/10px;\n\tfont-family: monospace, sans-serif}\n\nabbr[title], dfn[title] {\n\tborder: 2px}"
-        out = self.parser.parse(src)
+        test = "@charset utf-8;\n@import url(test);\n@media print { a:hover, a:active{outline:none}a, a:active, a:visited{color:#607890}a:hover{color:#036} }body:not(.test){margin-bottom:.5em;font-family:Georgia , sans-serif;*font:13px / 1.231 sans-serif}::selection{color:#f00}.test:hover{color:#f00}.test:hover:after{content:#00f}pre, code, kbd, samp{font:12px / 10px;font-family:monospace , sans-serif}abbr[title], dfn[title]{border:2px}"
+        out = self.parser.loads(src)
         self.assertEqual(test, out)
 
     def test_nesting_2(self):
@@ -61,8 +74,8 @@ class TestSCSS( unittest.TestCase ):
           li { float: left;
             a .test .main{ font-weight: bold; }
           } }"""
-        test = "#navbar {\n\twidth: 80%;\n\theight: 23px}\n\n#navbar ul {\n\tlist-style-type: none}\n\n#navbar li {\n\tfloat: left}\n\n#navbar li a .test .main {\n\tfont-weight: bold}"
-        out = self.parser.parse(src)
+        test = "#navbar{width:80%;height:23px}#navbar ul{list-style-type:none}#navbar li{float:left}#navbar li a .test .main{font-weight:bold}"
+        out = self.parser.loads(src)
         self.assertEqual(test, out)
 
     def test_nestproperties(self):
@@ -72,8 +85,8 @@ class TestSCSS( unittest.TestCase ):
                 left: { width: 4px; color: #888; }
                 right: { width: 2px; color: #ccc; }
             } }"""
-        test = ".fakeshadow {\n\tborder-style: solid;\n\tborder-right-width: 2px;\n\tborder-right-color: #ccc;\n\tborder-left-width: 4px;\n\tborder-left-color: #888}"
-        out = self.parser.parse(src)
+        test = ".fakeshadow{border-style:solid;border-right-width:2px;border-right-color:#ccc;border-left-width:4px;border-left-color:#888}"
+        out = self.parser.loads(src)
         self.assertEqual(test, out)
 
     def test_parent_references(self):
@@ -81,8 +94,8 @@ class TestSCSS( unittest.TestCase ):
             &:hover { color: #ffb3ff; }
             &:visited { color: #c458cb; }
             .test & { color: red; }}"""
-        test = "a {\n\tcolor: #ce4dd6}\n\na:hover {\n\tcolor: #ffb3ff}\n\na:visited {\n\tcolor: #c458cb}\n\n.test a {\n\tcolor: red}"
-        out = self.parser.parse(src)
+        test = "a{color:#ce4dd6}a:hover{color:#ffb3ff}a:visited{color:#c458cb}.test a{color:#f00}"
+        out = self.parser.loads(src)
         self.assertEqual(test, out)
 
     def test_variables(self):
@@ -93,8 +106,8 @@ class TestSCSS( unittest.TestCase ):
             $def_test: beep-beep !default;
             #navbar { border-bottom: { color: $main-color; style: $style; } }
             a.#{$def_test} { color: $main-color; &:hover { border-bottom: $style 1px; } }"""
-        test = "#navbar {\n\tborder-bottom-style: solid;\n\tborder-bottom-color: #ce4dd6}\n\na.second {\n\tcolor: #ce4dd6}\n\na.second:hover {\n\tborder-bottom: solid 1px}"
-        out = self.parser.parse(src)
+        test = "#navbar{border-bottom-style:solid;border-bottom-color:#ce4dd6}a.second{color:#ce4dd6}a.second:hover{border-bottom:solid 1px}"
+        out = self.parser.loads(src)
         self.assertEqual(test, out)
 
     def test_interpolation(self):
@@ -104,8 +117,8 @@ class TestSCSS( unittest.TestCase ):
             border-#{$side}-radius: $radius;
             -moz-border-radius-#{$side}: $radius;
             -webkit-border-#{$side}-radius: $radius; }"""
-        test = "div.rounded-top p {\n\tborder-top-radius: 10px;\n\t-moz-border-radius-top: 10px;\n\t-webkit-border-top-radius: 10px}"
-        out = self.parser.parse(src)
+        test = "div.rounded-top p{border-top-radius:10px;-moz-border-radius-top:10px;-webkit-border-top-radius:10px}"
+        out = self.parser.loads(src)
         self.assertEqual(test, out)
 
     def test_mixin_arg(self):
@@ -116,8 +129,8 @@ class TestSCSS( unittest.TestCase ):
             #navbar li { @include rounded(top); }
             #footer { @include rounded(top, 5px); }
             #sidebar { @include rounded(left, 8px); }"""
-        test = "#navbar li {\n\tborder-top-radius: 10px;\n\t-moz-border-radius-top: 10px;\n\t-webkit-border-top-radius: 10px}\n\n#footer {\n\tborder-top-radius: 5px;\n\t-moz-border-radius-top: 5px;\n\t-webkit-border-top-radius: 5px}\n\n#sidebar {\n\tborder-left-radius: 8px;\n\t-moz-border-radius-left: 8px;\n\t-webkit-border-left-radius: 8px}"
-        out = self.parser.parse(src)
+        test = "#navbar li{border-top-radius:10px;-moz-border-radius-top:10px;-webkit-border-top-radius:10px}#footer{border-top-radius:5px;-moz-border-radius-top:5px;-webkit-border-top-radius:5px}#sidebar{border-left-radius:8px;-moz-border-radius-left:8px;-webkit-border-left-radius:8px}"
+        out = self.parser.loads(src)
         self.assertEqual(test, out)
 
     def test_extend_rule(self):
@@ -128,30 +141,6 @@ class TestSCSS( unittest.TestCase ):
             .error .intrusion { background-image: url(/image/hacked.png); }
             .seriousError { @extend .error; border-width: 3px; }
             """
-        test = ".error, .seriousError {\n\tborder: 1px #f00;\n\tbackground-color: #fdd}\n\na:hover {\n\ttext-decoration: underline}\n\n.error .intrusion, .seriousError .intrusion {\n\tbackground-image: url(/image/hacked.png)}\n\n.seriousError {\n\tborder-width: 3px}"
-        out = self.parser.parse(src)
-        self.assertEqual(test, out)
-
-    def test_mixin(self):
-        src = """
-        @mixin font {
-            font: {
-                weight: inherit;
-                style: inherit;
-                size: 100%;
-                family: inherit; };
-            vertical-align: baseline; }
-        @mixin global { .global { border:red; @include font; }}
-        @include global;
-        @mixin rounded-top {
-            $side: top;
-            $radius: 10px;
-            border-#{$side}-radius: $radius;
-            -moz-border-radius-#{$side}: $radius;
-            -webkit-border-#{$side}-radius: $radius; }
-            #navbar li { @include rounded-top; }
-            #footer { @include rounded-top; }
-        """
-        test = ".global {\n\tborder: red;\n\tvertical-align: baseline;\n\tfont-weight: inherit;\n\tfont-style: inherit;\n\tfont-size: 100%;\n\tfont-family: inherit}\n\n#navbar li {\n\tborder-top-radius: 10px;\n\t-moz-border-radius-top: 10px;\n\t-webkit-border-top-radius: 10px}\n\n#footer {\n\tborder-top-radius: 10px;\n\t-moz-border-radius-top: 10px;\n\t-webkit-border-top-radius: 10px}"
-        out = self.parser.parse(src)
+        test = ".error, .seriousError{border:1px #f00;background-color:#fdd}a:hover{text-decoration:underline}.error .intrusion, .seriousError .intrusion{background-image:url(/image/hacked.png)}.seriousError{border-width:3px}"
+        out = self.parser.loads(src)
         self.assertEqual(test, out)
