@@ -9,7 +9,11 @@ from scss import parser, VERSION
 
 COMMANDS = ['import', 'option', 'mixin', 'include', 'for', 'if', 'else']
 
+
 def complete(text, state):
+    """ Auto complete scss constructions
+        in interactive mode.
+    """
     for cmd in COMMANDS:
         if cmd.startswith(text):
             if not state:
@@ -17,9 +21,11 @@ def complete(text, state):
             else:
                 state -= 1
 
+
 def main(argv=None):
 
     try:
+        # Upgrade shell in interactive mode
         import atexit
         import readline
         history = os.path.join(os.environ['HOME'], ".scss-history")
@@ -30,6 +36,7 @@ def main(argv=None):
     except ( ImportError, IOError ):
         pass
 
+    # Create options
     p = optparse.OptionParser(
         usage="%prog [OPTION]... [INFILE] [OUTFILE]",
         version="%prog " + VERSION,
@@ -70,8 +77,9 @@ The location of the generated CSS can be set using a colon:
     opts, args = p.parse_args(argv or sys.argv[1:])
     precache = opts.cache
 
+    # Interactive mode
     if opts.shell:
-        p = parser.Stylecheet()
+        p = parser.Stylesheet()
         print 'SCSS v. %s interactive mode' % VERSION
         print '================================'
         print 'Ctrl+D or quit for exit'
@@ -80,13 +88,14 @@ The location of the generated CSS can be set using a colon:
                 s = raw_input('>>> ').strip()
                 if s == 'quit':
                     raise EOFError
-                print p.parse(s)
-            except ( EOFError, KeyboardInterrupt ):
+                print p.loads(s)
+            except (EOFError, KeyboardInterrupt):
                 print '\nBye bye.'
                 break
 
         sys.exit()
 
+    # Watch mode
     elif opts.watch:
         self, sep, target = opts.watch.partition(':')
         files = []
@@ -103,7 +112,7 @@ The location of the generated CSS can be set using a colon:
         else:
             files.append([ self, target or self[:-5] + '.css', 0 ])
 
-        s = parser.Stylecheet(
+        s = parser.Stylesheet(
             options=dict(
                 comments = opts.comments,
                 compress = opts.compress,
@@ -117,8 +126,8 @@ The location of the generated CSS can be set using a colon:
             ttime = os.path.getmtime(infile)
             if mtime < ttime:
                 print " Parse '%s' to '%s' .. done" % ( infile, outfile )
-                s.load(open(infile, 'r'))
-                open(outfile, 'w').write(str(s))
+                out = s.load(open(infile, 'r'))
+                open(outfile, 'w').write(out)
                 f[2] = os.path.getmtime(outfile)
 
         print 'SCSS v. %s watch mode' % VERSION
@@ -138,6 +147,7 @@ The location of the generated CSS can be set using a colon:
         sys.exit()
 
 
+    # Default compile files
     elif not args:
         infile = sys.stdin
         outfile = sys.stdout
@@ -164,7 +174,7 @@ The location of the generated CSS can be set using a colon:
         sys.exit()
 
     try:
-        s = parser.Stylecheet(
+        s = parser.Stylesheet(
             options=dict(
                 comments = opts.comments,
                 compress = opts.compress,
@@ -172,8 +182,7 @@ The location of the generated CSS can be set using a colon:
                 sort = opts.sort,
                 cache = precache,
             ))
-        s.load( infile )
-        outfile.write( str(s) )
+        outfile.write(s.load(infile))
     except ValueError, e:
         raise SystemExit(e)
 
